;; Generated package description from org-transclusion-http.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "org-transclusion-http" "0.5pre0.20240630.1" "Transclude over HTTP" '((emacs "28.1") (org-transclusion "1.4.0") (plz "0.7.2")) :commit "4e3e5da22d22ab831f70c824cca77c357d2d7901" :authors '(("Joseph Turner" . "firstnameatushin.org")) :maintainer '("Joseph Turner" . "~ushin/ushin@lists.sr.ht") :url "https://git.sr.ht/~ushin/org-transclusion-http")
